(add-advisor! advisor)(advise context)(advise context advisors)Adds advice to a context such as {:form [:div]}.
Advice recommends a kind {:form [:div], :value [:div], :kind :kindly/hiccup}.
Works best with both form and value because metadata may appear on either.
If no value is present, will evaluate :form and populate :value and :kind.
Adds advice to a context such as `{:form [:div]}`.
Advice recommends a kind `{:form [:div], :value [:div], :kind :kindly/hiccup}`.
Works best with both form and value because metadata may appear on either.
If no value is present, will evaluate `:form` and populate `:value` and `:kind`.(set-advisors! advisors)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |